package org.semanticweb.elk.util.collections.chains;

/*
 * #%L
 * ELK Reasoner
 * $Id:$
 * $HeadURL:$
 * %%
 * Copyright (C) 2011 - 2012 Department of Computer Science, University of Oxford
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

/**
 * A class of matching an object of one type against elements of another type.
 * 
 * @author "Yevgeny Kazakov"
 * 
 * @param <I>
 *            the input type of elements that should be matched
 * @param <O>
 *            the output type of elements that satisfies the matching conditions
 */
public interface Matcher<I, O> {

	/**
	 * Tests whether the given element satisfies the matching conditions.
	 * 
	 * @param candidate
	 *            the candidate element to test
	 * @return the element which is physically equal (according to {@code ==})
	 *         to the input element, if the input element satisfies the matching
	 *         condition, or {@code null} otherwise.
	 */
	O match(I candidate);

}
